InSpec-Overlay-Bug
========================================================================

Bug
------------------------------------------------------------------------

When _Controls_ in an _overlay_ _Profile_ are created as multiple files,
e.g. one _Control_ per file, InSpec does not define the correct number
of _Controls_ nor the correct number of _Tests_.

Bottom Line Up Front (BLUF)
------------------------------------------------------------------------

| + Profile                  | __Single File Overlay__ | __Multiple File Overlay__ |
|:---------------------------|:-----------------------:|:-------------------------:|
| __Single File Underlay__   | Works                   | Not Working               |
| __Multiple File Underlay__ | Works                   | Not Working               |

The same results occur on:

* __CentOS 7.9__ using `inspec` __5.22.29__ and `cinc-auditor` __6.6.0__
* __RHEL 9.3__ using `inspec` __5.22.36__ and `cinc-auditor` __6.6.0__

Possible Fix
------------------------------------------------------------------------

Support for multiple _Control_ files is shown in InSpec's documentation
["Chef InSpec" -> "Profiles" -> "About Profiles" -> "Profile structure"](https://docs.chef.io/inspec/profiles/#profile-structure)
and reinforced by the fact that _Controls_ are contained in a directory
instead of a single file in the _Profile_ root directory.  Whether the
_Profile_ is used as a _underlay_ or _overlay_ should not restrict the
structure of the _Profile_.

Background
------------------------------------------------------------------------

In the test scenario the _underlay_ defines basic _Control_ metadata
properties.  The _overlay_ takes advantage of InSpec's capability to
[modify](https://docs.chef.io/inspec/profiles/depends/#modify-a-control)
_Control_ properties.  The _overlay_ adds or modifies properties, such as
`impact`, and then defines the tests in the `describe` block.

As documented in the
["Chef InSpec" -> "Profiles" -> "Dependencies" -> "Selectively include controls"](https://docs.chef.io/inspec/profiles/depends/#selectively-include-controls)
section, the `require_controls` "command selectively include(s) certain
controls from an included profile."  The expected behavior is that each
time that the `require_controls` command is executed that the defined
_Controls_ are added to a list of _Controls_ to execute.  Instead,
multiple calls on the command seem to overwrite or corrupt the list of
_Controls_ and _Tests_ to execute.

Bug Test Usage
------------------------------------------------------------------------

* Unzip the archive.

* Execute `bash ./Test-All.sh` to run all four permutations of the test.

* Modify the `engine` variable in the `Test-All.sh` script to change between using `inspec` and `cinc-auditor` for the tests.
